<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>ClipboardItem</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="33"/>
        <source>Clipboard</source>
        <translation>Mübadilə yaddaşı</translation>
    </message>
    <message>
        <location filename="../dock-clipboard-plugin/clipboarditem.cpp" line="64"/>
        <source>Open</source>
        <translation>Açın</translation>
    </message>
</context>
<context>
    <name>ClipboardPlugin</name>
    <message>
        <location filename="../dock-clipboard-plugin/clipboardplugin.cpp" line="44"/>
        <source>Clipboard</source>
        <translation>Mübadilə yaddaşı</translation>
    </message>
</context>
<context>
    <name>ItemData</name>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="130"/>
        <source>Picture</source>
        <translation>Şəkil</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="132"/>
        <source>Text</source>
        <translation>Mətn</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="134"/>
        <source>File</source>
        <translation>Fayl</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemdata.cpp" line="146"/>
        <source>%1 characters</source>
        <translation>%1 simvollar</translation>
    </message>
</context>
<context>
    <name>ItemWidget</name>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="369"/>
        <source>%1 files (%2...)</source>
        <translation>%1 fayl (%2...)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="420"/>
        <location filename="../dde-clipboard/itemwidget.cpp" line="609"/>
        <source>(File deleted)</source>
        <translation>(Fayl silinib)</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="443"/>
        <source>Yesterday</source>
        <translation>Dünən</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="449"/>
        <source>Just now</source>
        <translation>İndicə</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="451"/>
        <source>1 minute ago</source>
        <translation>1 dəqiqə əvvəl</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="453"/>
        <source>%1 minutes ago</source>
        <translation>%1 dəqiqə əvvəl</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="455"/>
        <source>1 hour ago</source>
        <translation>1 saat əvvəl</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/itemwidget.cpp" line="457"/>
        <source>%1 hours ago</source>
        <translation>%1 saat əvvəl</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="301"/>
        <source>Clipboard</source>
        <translation>Mübadilə yaddaşı</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="304"/>
        <source>Clear all</source>
        <translation>Hamısını təmizlə</translation>
    </message>
    <message>
        <location filename="../dde-clipboard/mainwindow.cpp" line="329"/>
        <source>Copy the content to clipboard</source>
        <translation>Məzmunu mübadilə yaddaşına kopyalamaq</translation>
    </message>
</context>
</TS>